## $Id: applicant.py 13291 2015-10-07 09:29:52Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from zope.interface import implementedBy
from waeup.kofa.applicants.applicant import Applicant, ApplicantFactory
from waeup.kofa.utils.helpers import attrs_to_fields
from kofacustom.nigeria.applicants.interfaces import(
    INigeriaApplicant,
    INigeriaUGApplicantEdit, INigeriaPGApplicantEdit,
    IPUTMEApplicantEdit)

class NigeriaApplicant(Applicant):

    grok.implements(INigeriaApplicant, INigeriaUGApplicantEdit,
        INigeriaPGApplicantEdit, IPUTMEApplicantEdit)
    grok.provides(INigeriaApplicant)

    applicant_student_mapping = Applicant.applicant_student_mapping + [
        ('lga', 'lga'),
        ('nationality', 'nationality'),
        ('fst_sit_fname', 'fst_sit_fname'),
        ('fst_sit_no', 'fst_sit_no'),
        ('fst_sit_date', 'fst_sit_date'),
        ('fst_sit_type', 'fst_sit_type'),
        ('fst_sit_results', 'fst_sit_results'),
        ('scd_sit_fname', 'scd_sit_fname'),
        ('scd_sit_no', 'scd_sit_no'),
        ('scd_sit_date', 'scd_sit_date'),
        ('scd_sit_type', 'scd_sit_type'),
        ('scd_sit_results', 'scd_sit_results'),
        ('hq_type', 'hq_type'),
        ('hq_fname', 'hq_fname'),
        ('hq_matric_no', 'hq_matric_no'),
        ('hq_degree', 'hq_degree'),
        ('hq_school', 'hq_school'),
        ('hq_session', 'hq_session'),
        ('hq_disc', 'hq_disc'),
        ]

    def _setStudyCourseAttributes(self, studycourse):
        if self.applicant_id.startswith('pude'):
            studycourse.entry_mode = u'de_ft'
            studycourse.current_level = 200
        else:
            studycourse.entry_mode = self.course_admitted.study_mode
            studycourse.current_level = self.course_admitted.start_level
        studycourse.certificate = self.course_admitted
        studycourse.entry_session = self.__parent__.year
        studycourse.current_session = self.__parent__.year
        return

# Set all attributes of NigeriaApplicant required in INigeriaApplicant as field
# properties. Doing this, we do not have to set initial attributes
# ourselves and as a bonus we get free validation when an attribute is
# set.
NigeriaApplicant = attrs_to_fields(NigeriaApplicant)

class NigeriaApplicantFactory(ApplicantFactory):
    """A factory for customized applicants.
    """

    def __call__(self, *args, **kw):
        return NigeriaApplicant()

    def getInterfaces(self):
        return implementedBy(NigeriaApplicant)
